@@ -1,17 +1,19 @@
 #' Compute a pairwise Jost's D matrix between populations
 #'
 #' @description The function computes the pairwise Jost's D matrix between
-#' populations from an object of class \code{genind} or directly from a GENEPOP file.
+#' populations from an object of class \code{genind} or directly
+#' from a GENEPOP file.
 #'
 #' @param x An object of class \code{genind}, or the character string indicating
 #' the path of the GENEPOP file.
 #' @param pop_names (optional) A vector of class \code{character} of the same
-#' length as the number of populations (rows' and columns' number in the returned
+#' length as the number of populations (row and column number in the returned
 #' matrix). It contains the name of the populations.
 #' @return A pairwise \code{matrix} of G'ST with as many rows and columns as
 #' there are populations in the input data.
 #' @details The formula used is that of Jost (2008)
-#' This functions uses directly the function \code{diffCalc} from \pkg{diveRsity}.
+#' This functions uses directly the function \code{diffCalc}
+#' from \pkg{diveRsity}.
 #' See \url{http://genepop.curtin.edu.au/help_input.html} for details on the
 #' GENEPOP file format and see Raymond (1995) for detail about GENEPOP software.
 #' @section Warnings:
@@ -19,7 +21,7 @@
 #' \itemize{
 #' \item If \code{x} is an object of class \code{genind}, individuals are
 #' re-ordered by populations and populations are ordered in alphabetic order.
-#' \item If \code{x} is the path to a GENEPOP file, populations' order
+#' \item If \code{x} is the path to a GENEPOP file, population order
 #' in \code{pop_names} must be the same as in the GENEPOP file.
 #' }
 #' Negative values are converted into 0
@@ -43,7 +45,7 @@
 mat_pw_d_j <- function(x, pop_names = NULL){
 
   # If 'x' is a 'genind' object
-  if (class(x) == "genind"){
+  if (inherits(x, "genind")){
     # Create a temporary text file name
     tmp <- tempfile(fileext = ".txt")
     # Convert the 'genind' object into a GENEPOP formatted text file
@@ -64,7 +66,7 @@ mat_pw_d_j <- function(x, pop_names = NULL){
     row.names(mat_d_j) <- colnames(mat_d_j) <- pop_names
 
   # If 'x' is the path to a GENEPOP formatted text file
-  } else if (class(x) == "character"){
+  } else if (inherits(x, "character")){
 
     # Compute the distance matrix between populations using diffCalc from
     # diveRsity package, directly from the GENEPOP file
